@@ -1,4 +1,4 @@
-package Pcore::PDF v0.4.1;
+package Pcore::PDF v0.4.2;
 
 use Pcore -dist, -class, -const, -result;
 use Config;
@@ -138,7 +138,7 @@ sub update_all ( $self, $cb = undef ) {
 }
 
 # TODO MSWIN support
-sub _build_prince ($self) {
+sub _build_bin ($self) {
     my $princexml_ver = $ENV->dist('Pcore-PDF')->cfg->{princexml_ver};
 
     my $path = '/bin/princexml-linux-generic' . ( $Config{archname} =~ /x64|x86_64/sm ? '-x64' : q[] ) . "-$princexml_ver/lib/prince/bin/prince";
